==> gdnsd_1.11.1.orig.tar.xz: gdnsd-1.11.1/plugins/meta/libgdmaps/t/t99_loadonly.c <==
/* Copyright © 2012 Brandon L Black <blblack@gmail.com>
 *
 * This file is part of gdnsd-plugin-geoip.
 *
 * gdnsd-plugin-geoip is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * gdnsd-plugin-geoip is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gdnsd.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

// Unit test for gdmaps

#include "config.h"
#include <gdnsd/log.h>
#include "gdmaps_test.h"

int main(int argc, char* argv[]) {
    if(argc != 2)
        log_fatal("root directory must be set on commandline");

    gdmaps_t* gdmaps = gdmaps_test_init(argv[1]);
    unsigned tnum = 0;
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.2.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.0.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.15.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.125.18.68");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "69.58.186.119");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.125.0.0"); // edge-case, Ireland
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.124.255.255"); // edge-case, Ukraine
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::69.58.186.119"); // v4-compat
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::FFFF:69.58.186.119"); // v4-mapped
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::FFFF:0:69.58.186.119"); // SIIT
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2002:453A:BA77::"); // 6to4
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2001::BAC5:4588"); // Teredo
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2600:3c00::f03c:91ff:fe96:6a4f"); // native v6, defaulted
    gdmaps_destroy(gdmaps);
}

==> gdnsd_2.1.2.orig.tar.xz: gdnsd-2.1.2/plugins/meta/libgdmaps/t/t99_loadonly.c <==
/* Copyright © 2012 Brandon L Black <blblack@gmail.com>
 *
 * This file is part of gdnsd.
 *
 * gdnsd-plugin-geoip is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * gdnsd-plugin-geoip is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with gdnsd.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

// Unit test for gdmaps

#include "config.h"
#include <gdnsd/log.h>
#include "gdmaps_test.h"

static gdmaps_t* gdmaps = NULL;

int main(int argc, char* argv[]) {
    if(argc != 2)
        log_fatal("root directory must be set on commandline");

    gdmaps = gdmaps_test_init(argv[1]);
    unsigned tnum = 0;
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.2.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.0.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "192.0.15.1");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.125.18.68");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "69.58.186.119");
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.125.0.0"); // edge-case, Ireland
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "79.124.255.255"); // edge-case, Ukraine
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::69.58.186.119"); // v4-compat
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::FFFF:69.58.186.119"); // v4-mapped
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "::FFFF:0:69.58.186.119"); // SIIT
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2002:453A:BA77::"); // 6to4
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2001::BAC5:4588"); // Teredo
    gdmaps_lookup_noop(tnum++, gdmaps, "my_prod_map", "2600:3c00::f03c:91ff:fe96:6a4f"); // native v6, defaulted
}
